**General informations**

[![Python Version](https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10-blue.svg)](https://pypi.org/project/kedro-pandera/) [![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://opensource.org/license/apache-2-0/) [![Code Style: Black](https://img.shields.io/badge/code%20style-black-black.svg)](https://github.com/ambv/black)
[![SemVer](https://img.shields.io/badge/semver-2.0.0-green)](https://semver.org/)

----------------------------------------------------------
| Software repository | Latest release                                                                                                                             | Total downloads                                                                                                                    |
| ------------------- | ------------------------------------------------------------------------------------------------------------------------------------------ | ---------------------------------------------------------------------------------------------------------------------------------- |
| Pypi                | [![PyPI version](https://badge.fury.io/py/kedro-pandera.svg)](https://pypi.org/project/kedro-pandera/) | [![Downloads](https://pepy.tech/badge/kedro-pandera)](https://pepy.tech/project/kedro-pandera) |

**Code health**

----------------------------------------------------------
| Branch                                | Tests                                                                                                                                                                                                                                    | Coverage                                                                                                                                                                                                                                                                                               | Links                                                                                                                                                                                                                                                                                                                                                 | Documentation                                                                                                                                                                 | Deployment                                                                                                                                                                                                                                                                                                                                      | Activity                                                                                                                                                                                                                                                                     |
| ------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `main` | [![test](https://github.com/Galileo-Galilei/kedro-pandera/workflows/test/badge.svg?branch=main)](https://github.com/Galileo-Galilei/kedro-pandera/actions?query=workflow%3Atest+branch%3Amain) | [![codecov](https://codecov.io/gh/Galileo-Galilei/kedro-pandera/branch/main/graph/badge.svg)](https://codecov.io/gh/Galileo-Galilei/kedro-pandera/branch/main) | [![links](https://github.com/Galileo-Galilei/kedro-pandera/workflows/check-links/badge.svg?branch=main)](https://github.com/Galileo-Galilei/kedro-pandera/actions?query=workflow%3Acheck-links+branch%3Amain) | [![Documentation](https://readthedocs.org/projects/kedro-pandera/badge/?version=stable)](https://kedro-pandera.readthedocs.io/en/stable/) | [![publish](https://github.com/Galileo-Galilei/kedro-pandera/workflows/publish/badge.svg?branch=main)](https://github.com/Galileo-Galilei/kedro-pandera/actions?query=branch%3Amain+workflow%3Apublish) | [![commit](https://img.shields.io/github/commits-since/Galileo-Galilei/kedro-pandera/0.2.2)](https://github.com/Galileo-Galilei/kedro-pandera/compare/0.2.2...main) |

# What is kedro-pandera?


# How do I install kedro-pandera?


``kedro-pandera`` is available on PyPI, so you can install it with ``pip``:

```console
pip install kedro-pandera
```

If you want to use the most up to date version of the package which is under development and not released yet, you can install the package from github:

```console
pip install --upgrade git+https://github.com/Galileo-Galilei/kedro-pandera.git
```


# Getting started

The documentation contains:

- [A "hello world" example](https://kedro-pandera.readthedocs.io/en/stable/source/01_tutorials/01_getting_started.html)

# Release and roadmap

The [release history](https://github.com/Galileo-Galilei/kedro-pandera/blob/main/CHANGELOG.md) centralizes packages improvements across time. The main features coming in next releases are [listed on github milestones](https://github.com/Galileo-Galilei/kedro-pandera/milestones). Feel free to upvote/downvote and discuss prioritization in associated issues.

# Disclaimer

This package is still in active development. We use [SemVer](https://semver.org/) principles to version our releases. Until we reach `1.0.0` milestone, breaking changes will lead to `<minor>` version number increment, while releases which do not introduce breaking changes in the API will lead to `<patch>` version number increment.

If you want to see how to migrate from one version of `kedro-pandera` to another, see the [migration guide](./docs/source/migration_guide.md).

# Can I contribute?

We'd be happy to receive help to maintain and improve the package. Any PR will be considered (from typo in the docs to core features add-on) Please check the [contributing guidelines](https://github.com/Galileo-Galilei/kedro-pandera/blob/main/CONTRIBUTING.md).

# Main contributors

The following people actively maintain, enhance and discuss design to make this package as good as possible:

- [Yolan Honoré-Rougé](https://github.com/Galileo-Galilei)
- [Nok Lam Chan](https://github.com/noklam)
- [Joel Schwarzmann](https://github.com/datajoely)
